@@ -1,10 +1,11 @@
-from typing import Optional
+from typing import Literal, Optional
 
 from aiohttp.client import ClientSession
 
 from pypixiv.http import PixivHttpClient
-from pypixiv.models.illust import IllustInfo
-from pypixiv.models.user import UserFullInfo, UserInfo
+from pypixiv.illust.model import IllustInfo
+from pypixiv.user.model import UserFullInfo, UserInfo
+from pypixiv.ranking.model import RankingInfo
 
 
 class PixivClient(PixivHttpClient):
@@ -25,3 +26,8 @@ class PixivClient(PixivHttpClient):
 
     async def illustinfo(self, illust_id: int):
         return IllustInfo(await self.get_illust(illust_id))
+
+    async def ranking(
+        self, mode: Literal["daily", "weekly", "monthly"], date: Optional[str]
+    ):
+        return RankingInfo(await self.get_ranking(mode, date))
